/***************************************************************************
 *  IChannelGroup.cs
 *
 *  Copyright (C) 2006 INdT
 *  Written by 
 *	Andre Moreira Magalhaes <andre.magalhaes@indt.org.br>
 *	Kenneth Christiansen <kenneth.christiansen@gmail.com>
 *	Renato Araujo Oliveira Filho <renato.filho@indt.org>
 ****************************************************************************/

/*  THIS FILE IS LICENSED UNDER THE MIT LICENSE AS OUTLINED IMMEDIATELY BELOW:
 *
 *  Permission is hereby granted, free of charge, to any person obtaining a
 *  copy of this software and associated documentation files (the "Software"),
 *  to deal in the Software without restriction, including without limitation
 *  the rights to use, copy, modify, merge, publish, distribute, sublicense,
 *  and/or sell copies of the Software, and to permit persons to whom the
 *  Software is furnished to do so, subject to the following conditions:
 *
 *  The above copyright notice and this permission notice shall be included in
 *  all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 *  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 *  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 *  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 *  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
 *  FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
 *  DEALINGS IN THE SOFTWARE.
 */

using System;
using NDesk.DBus;
using org.freedesktop.DBus;

namespace org.freedesktop.Telepathy
{
	public delegate void GroupFlagsChangedHandler (uint added, uint removed);
	public delegate void MembersChangedHandler (string message, uint[] added, uint[] removed, uint[] local_pending, uint[] remote_pending, uint actor, uint reason);

	public enum ChannelGroupFlag : uint
	{
		CanAdd = 1,
		CanRemove = 2,
		CanRescind = 4,
		MessageAdd = 8,
		MessageRemove = 16,
		MessageAccept = 32,
		MessageReject = 64,
		MessageRescind = 128,
		SpecificHandles = 256
	}

	[Interface ("org.freedesktop.Telepathy.Channel.Interface.Group")]
	public interface IChannelGroup
	{
		event GroupFlagsChangedHandler GroupFlagsChanged;
		event MembersChangedHandler MembersChanged;

		void AddMembers (uint[] contacts, string message);
		uint[][][] AllMembers { get; }
		uint GroupFlags { get; }
		uint[] GetHandleOwners (uint[] handles);
		uint[] LocalPendingMembers { get; }
		uint[] Members { get; }
		uint[] RemotePendingMembers { get; }
		uint SelfHandle { get; }
		void RemoveMembers (uint[] contacts, string message);
	}
}
